==> 3.0.14.tar.gz: android/src/main/kotlin/com/pravera/activity_rec_flutter/service/ActivityRecognitionIntentService.kt <==
package com.pravera.activity_rec_flutter.service

import DatabaseHelper
import android.annotation.SuppressLint
import android.app.Activity
import android.content.Context
import android.content.Intent
import android.os.CountDownTimer
import androidx.core.app.JobIntentService
import com.google.android.gms.location.ActivityRecognitionResult
import com.google.android.gms.location.DetectedActivity
import com.google.gson.Gson
import com.pravera.activity_rec_flutter.Constants
import com.pravera.activity_rec_flutter.errors.ErrorCodes
import com.pravera.activity_rec_flutter.models.ActivityData
import com.pravera.activity_rec_flutter.utils.ActivityRecognitionUtils
import com.pravera.activity_rec_flutter.utils.SharedPreferenceManager
import android.util.Log

class ActivityRecognitionIntentService : JobIntentService() {

    lateinit var mPrefs: SharedPreferenceManager
    val prefRecordedActivity = "prefRecordedActivity"
    val prefRecordedActivityTime = "prefRecordedActivityTime"

    companion object {
        val jsonConverter: Gson = Gson()
        fun enqueueWork(context: Context, intent: Intent) {
            enqueueWork(
                context, ActivityRecognitionIntentService::class.java,
                Constants.ACTIVITY_RECOGNITION_INTENT_SERVICE_JOB_ID, intent
            )
        }
    }

    @SuppressLint("LongLogTag")
    override fun onHandleWork(intent: Intent) {
        val extractedResult = ActivityRecognitionResult.extractResult(intent)
        val probableActivities = extractedResult?.probableActivities
        val mostProbableActivity = probableActivities?.maxByOrNull { it.confidence } ?: return

        mPrefs = SharedPreferenceManager(this)

        val activityData = ActivityData(
            ActivityRecognitionUtils.getActivityTypeFromValue(mostProbableActivity.type),
            ActivityRecognitionUtils.getActivityConfidenceFromValue(mostProbableActivity.confidence)
        )

        var recordedActivity = mPrefs.getString("prefRecordedActivity", "")
        var recordedActivityTime = mPrefs.getLong("prefRecordedActivityTime", 0L)
        Log.d("ActivityRecognitionIntentService", "activity type =====> ${activityData.type}")
        Log.d("ActivityRecognitionIntentService", "recordedActivity =====> ${recordedActivity}")
        Log.d("ActivityRecognitionIntentService", "recordedActivityTime =====> ${recordedActivityTime}")

        if (recordedActivity == "") {
            Log.d("ActivityRecognitionIntentService", " =====> recordedActivity == null")
            mPrefs.putString("prefRecordedActivity",activityData.type)
            mPrefs.putLong("prefRecordedActivityTime",System.currentTimeMillis())
        } else {
            Log.d("ActivityRecognitionIntentService", " =====> recordedActivity != null")
            if (activityData.type != recordedActivity) {
                Log.d("ActivityRecognitionIntentService", " =====> activityData != recordedActivity")
                val timeDifferenceMillis = System.currentTimeMillis() - recordedActivityTime

                // Convert milliseconds to minutes
                val timeDifferenceMinutes = timeDifferenceMillis / 60000
                mPrefs.putString("prefRecordedActivity",activityData.type)
                mPrefs.putLong("prefRecordedActivityTime",System.currentTimeMillis())

                when (activityData.type) {
                    "IN_VEHICLE" -> {
                        val points = timeDifferenceMinutes.toInt() * 10 // per minute 10 points for vehicle
                        val storedPoints = mPrefs.getInt("_prefCurrentInVehiclePoints", 0)
                        mPrefs.putInt("_prefCurrentInVehiclePoints", storedPoints + points.toInt())
                    }

                    "ON_BICYCLE" -> {
                        val points = timeDifferenceMinutes.toInt() * 8 // per minute 8 points for bycicle
                        val storedPoints = mPrefs.getInt("_prefCurrentOnByciclePoints", 0)
                        mPrefs.putInt("_prefCurrentOnByciclePoints", storedPoints + points.toInt())
                    }

                    "RUNNING" -> {
                        val points = timeDifferenceMinutes.toInt() * 6 // per minute 6 points for running
                        val storedPoints = mPrefs.getInt("_prefCurrentRunningPoints", 0)
                        mPrefs.putInt("_prefCurrentRunningPoints", storedPoints + points.toInt())
                    }

                    "WALKING" -> {
                        val points = timeDifferenceMinutes.toInt() * 4 // per minute 4 points for walking
                        val storedPoints = mPrefs.getInt("_prefCurrentWalkingPoints", 0)
                        mPrefs.putInt("_prefCurrentWalkingPoints", storedPoints + points.toInt())
                    }

                    "STILL" -> {
                        val points = timeDifferenceMinutes.toInt() * 2 // per minute 2 points for still
                        val storedPoints = mPrefs.getInt("_prefCurrentStillPoints", 0)
                        mPrefs.putInt("_prefCurrentStillPoints", storedPoints + points.toInt())
                    }

                    else -> println("UNKNOWN activity")
                }
            }
        }


        val dbHelper = DatabaseHelper(this)
        dbHelper.addRecord(activityData.type, activityData.confidence, System.currentTimeMillis().toString())
        //dbHelper.getRecords()


        var prefsKey: String
        var prefsValue: String
        try {
            prefsKey = Constants.ACTIVITY_DATA_PREFS_KEY
            prefsValue = jsonConverter.toJson(activityData)
        } catch (e: Exception) {
            prefsKey = Constants.ACTIVITY_ERROR_PREFS_KEY
            prefsValue = ErrorCodes.ACTIVITY_DATA_ENCODING_FAILED.toString()
        }

        val prefs = getSharedPreferences(
            Constants.ACTIVITY_RECOGNITION_RESULT_PREFS_NAME, Context.MODE_PRIVATE
        ) ?: return
        with(prefs.edit()) {
            putString(prefsKey, prefsValue)
            commit()
        }
    }
}

==> 3.0.15.tar.gz: android/src/main/kotlin/com/pravera/activity_rec_flutter/service/ActivityRecognitionIntentService.kt <==
package com.pravera.activity_rec_flutter.service

import DatabaseHelper
import android.annotation.SuppressLint
import android.app.Activity
import android.content.Context
import android.content.Intent
import android.os.CountDownTimer
import androidx.core.app.JobIntentService
import com.google.android.gms.location.ActivityRecognitionResult
import com.google.android.gms.location.DetectedActivity
import com.google.gson.Gson
import com.pravera.activity_rec_flutter.Constants
import com.pravera.activity_rec_flutter.errors.ErrorCodes
import com.pravera.activity_rec_flutter.models.ActivityData
import com.pravera.activity_rec_flutter.utils.ActivityRecognitionUtils
import com.pravera.activity_rec_flutter.utils.SharedPreferenceManager
import android.util.Log

class ActivityRecognitionIntentService : JobIntentService() {

    lateinit var mPrefs: SharedPreferenceManager
    val prefRecordedActivity = "prefRecordedActivity"
    val prefRecordedActivityTime = "prefRecordedActivityTime"

    companion object {
        val jsonConverter: Gson = Gson()
        fun enqueueWork(context: Context, intent: Intent) {
            enqueueWork(
                context, ActivityRecognitionIntentService::class.java,
                Constants.ACTIVITY_RECOGNITION_INTENT_SERVICE_JOB_ID, intent
            )
        }
    }

    @SuppressLint("LongLogTag")
    override fun onHandleWork(intent: Intent) {
        val extractedResult = ActivityRecognitionResult.extractResult(intent)
        val probableActivities = extractedResult?.probableActivities
        val mostProbableActivity = probableActivities?.maxByOrNull { it.confidence } ?: return

        mPrefs = SharedPreferenceManager(this)

        val activityData = ActivityData(
            ActivityRecognitionUtils.getActivityTypeFromValue(mostProbableActivity.type),
            ActivityRecognitionUtils.getActivityConfidenceFromValue(mostProbableActivity.confidence)
        )

        var recordedActivity = mPrefs.getString("prefRecordedActivity", "")
        var recordedActivityTime = mPrefs.getLong("prefRecordedActivityTime", 0L)
        Log.d("ActivityRecognitionIntentService", "activity type =====> ${activityData.type}")
        Log.d("ActivityRecognitionIntentService", "recordedActivity =====> ${recordedActivity}")
        Log.d("ActivityRecognitionIntentService", "recordedActivityTime =====> ${recordedActivityTime}")

        if (recordedActivity == "") {
            Log.d("ActivityRecognitionIntentService", " =====> recordedActivity == null")
            mPrefs.putString("prefRecordedActivity",activityData.type)
            mPrefs.putLong("prefRecordedActivityTime",System.currentTimeMillis())
        } else {
            Log.d("ActivityRecognitionIntentService", " =====> recordedActivity != null")
            if (activityData.type != recordedActivity) {
                Log.d("ActivityRecognitionIntentService", " =====> activityData != recordedActivity")
                val timeDifferenceMillis = System.currentTimeMillis() - recordedActivityTime

                // Convert milliseconds to minutes
                val timeDifferenceMinutes = timeDifferenceMillis / 60000
                mPrefs.putString("prefRecordedActivity",activityData.type)
                mPrefs.putLong("prefRecordedActivityTime",System.currentTimeMillis())

                when (activityData.type) {
                    "IN_VEHICLE" -> {
                        val points = timeDifferenceMinutes.toInt() * 10 // per minute 10 points for vehicle
                        val storedPoints = mPrefs.getString("_prefCurrentInVehiclePoints", "0")
                        mPrefs.putString("_prefCurrentInVehiclePoints", (storedPoints.toInt() + points.toInt()).toString())
                    }

                    "ON_BICYCLE" -> {
                        val points = timeDifferenceMinutes.toInt() * 8 // per minute 8 points for bycicle
                        val storedPoints = mPrefs.getString("_prefCurrentOnByciclePoints", "0")
                        mPrefs.putString("_prefCurrentOnByciclePoints", (storedPoints.toInt() + points.toInt()).toString())
                    }

                    "RUNNING" -> {
                        val points = timeDifferenceMinutes.toInt() * 6 // per minute 6 points for running
                        val storedPoints = mPrefs.getString("_prefCurrentRunningPoints", "0")
                        mPrefs.putString("_prefCurrentRunningPoints", (storedPoints.toInt() + points.toInt()).toString())
                    }

                    "WALKING" -> {
                        val points = timeDifferenceMinutes.toInt() * 4 // per minute 4 points for walking
                        val storedPoints = mPrefs.getString("_prefCurrentWalkingPoints", "0")
                        mPrefs.putString("_prefCurrentWalkingPoints", (storedPoints.toInt() + points.toInt()).toString())
                    }

                    "STILL" -> {
                        val points = timeDifferenceMinutes.toInt() * 2 // per minute 2 points for still
                        val storedPoints = mPrefs.getString("_prefCurrentStillPoints", "0")
                        mPrefs.putString("_prefCurrentStillPoints", (storedPoints.toInt() + points.toInt()).toString())
                    }

                    else -> println("UNKNOWN activity")
                }
            }
        }


        val dbHelper = DatabaseHelper(this)
        dbHelper.addRecord(activityData.type, activityData.confidence, System.currentTimeMillis().toString())
        //dbHelper.getRecords()


        var prefsKey: String
        var prefsValue: String
        try {
            prefsKey = Constants.ACTIVITY_DATA_PREFS_KEY
            prefsValue = jsonConverter.toJson(activityData)
        } catch (e: Exception) {
            prefsKey = Constants.ACTIVITY_ERROR_PREFS_KEY
            prefsValue = ErrorCodes.ACTIVITY_DATA_ENCODING_FAILED.toString()
        }

        val prefs = getSharedPreferences(
            Constants.ACTIVITY_RECOGNITION_RESULT_PREFS_NAME, Context.MODE_PRIVATE
        ) ?: return
        with(prefs.edit()) {
            putString(prefsKey, prefsValue)
            commit()
        }
    }
}
